@@ -13,37 +13,46 @@ NULL
 
 #' @section `use_travis()`:
 #' Adds a basic `.travis.yml` to the top-level directory of a package. This is a
-#' configuration file for the [Travis CI](https://travis-ci.org/) continuous
+#' configuration file for the [Travis CI](https://travis-ci.com/) continuous
 #' integration service.
 #' @param browse Open a browser window to enable automatic builds for the
 #'   package.
-#' @param ext which travis website to use. default to `"org"`for
-#'   https://travis-ci.org. Change to `"com"` for https://travis-ci.com.
+#' @param ext Which travis website to use. Defaults to `"com"` for
+#'   https://travis-ci.com. Change to `"org"` for https://travis-ci.org.
 #' @export
 #' @rdname ci
-use_travis <- function(browse = interactive(), ext = c("org", "com")) {
+use_travis <- function(browse = rlang::is_interactive(), ext = c("com", "org")) {
   check_uses_github()
-  ext <- rlang::arg_match(ext)
+  ext <- arg_match(ext)
   new <- use_template(
     "travis.yml",
     ".travis.yml",
     ignore = TRUE
   )
-  if (!new) return(invisible(FALSE))
+  if (!new) {
+    return(invisible(FALSE))
+  }
 
   travis_activate(browse, ext = ext)
   use_travis_badge(ext = ext)
   invisible(TRUE)
 }
 
-use_travis_badge <- function(ext = "org") {
+#' @section `use_travis_badge()`:
+#' Only adds the [Travis CI](https://travis-ci.com/) badge. Use for a project
+#'  where Travis is already configured.
+#' @export
+#' @rdname ci
+use_travis_badge <- function(ext = c("com", "org")) {
   check_uses_github()
+  ext <- arg_match(ext)
   url <- glue("https://travis-ci.{ext}/{github_repo_spec()}")
   img <- glue("{url}.svg?branch=master")
   use_badge("Travis build status", url, img)
 }
 
-travis_activate <- function(browse = interactive(), ext = "org") {
+travis_activate <- function(browse = is_interactive(), ext = c("com", "org")) {
+  ext <- arg_match(ext)
   url <- glue("https://travis-ci.{ext}/profile/{github_owner()}")
 
   ui_todo("Turn on travis for your repo at {url}")
@@ -64,7 +73,7 @@ check_uses_travis <- function(base_path = proj_get()) {
 
   ui_stop(
     "
-    Cannot detect that package {ui_(project_name(base_path))} already uses Travis.
+    Cannot detect that package {ui_value(project_name(base_path))} already uses Travis.
     Do you need to run {ui_code('use_travis()')}?
     "
   )
@@ -76,11 +85,13 @@ check_uses_travis <- function(base_path = proj_get()) {
 #' integration service for Windows.
 #' @export
 #' @rdname ci
-use_appveyor <- function(browse = interactive()) {
+use_appveyor <- function(browse = rlang::is_interactive()) {
   check_uses_github()
 
   new <- use_template("appveyor.yml", ignore = TRUE)
-  if (!new) return(invisible(FALSE))
+  if (!new) {
+    return(invisible(FALSE))
+  }
 
   appveyor_activate(browse)
   use_appveyor_badge()
@@ -88,7 +99,7 @@ use_appveyor <- function(browse = interactive()) {
   invisible(TRUE)
 }
 
-appveyor_activate <- function(browse = interactive()) {
+appveyor_activate <- function(browse = is_interactive()) {
   url <- "https://ci.appveyor.com/projects/new"
   ui_todo("Turn on AppVeyor for this repo at {url}")
   if (browse) {
@@ -96,6 +107,11 @@ appveyor_activate <- function(browse = interactive()) {
   }
 }
 
+#' @section `use_appveyor_badge()`:
+#' Only adds the [AppVeyor](https://www.appveyor.com) badge. Use for a project
+#'  where AppVeyor is already configured.
+#' @export
+#' @rdname ci
 use_appveyor_badge <- function() {
   appveyor <- appveyor_info()
   use_badge("AppVeyor build status", appveyor$url, appveyor$img)
@@ -125,7 +141,9 @@ use_gitlab_ci <- function() {
     ".gitlab-ci.yml",
     ignore = TRUE
   )
-  if (!new) return(invisible(FALSE))
+  if (!new) {
+    return(invisible(FALSE))
+  }
 
   invisible(TRUE)
 }
@@ -142,8 +160,79 @@ check_uses_gitlab_ci <- function(base_path = proj_get()) {
 
   ui_stop(
     "
-    Cannot detect that package {ui_(project_name(base_path))} already uses GitLab CI.
+    Cannot detect that package {ui_value(project_name(base_path))} already uses GitLab CI.
     Do you need to run {ui_code('use_gitlab_ci()')}?
     "
   )
 }
+
+#' @section `use_circleci()`:
+#' Adds a basic `.circleci/config.yml` to the top-level directory of a package. This is a
+#' configuration file for the [CircleCI](https://circleci.com/) continuous
+#' integration service.
+#' @param image The Docker image to use for build. Must be available on
+#'   [DockerHub](https://hub.docker.com). The
+#'   [rocker/verse](https://hub.docker.com/r/rocker/verse) image includes TeX
+#'   Live, pandoc, and the tidyverse packages. For a minimal image, try
+#'   [rocker/r-ver](https://hub.docker.com/r/rocker/r-ver). To specify a version
+#'   of R, change the tag from `latest` to the version you want, e.g.
+#'   `rocker/r-ver:3.5.3`.
+#' @export
+#' @rdname ci
+use_circleci <- function(browse = rlang::is_interactive(), image = "rocker/verse:latest") {
+  check_uses_github()
+  use_directory(".circleci", ignore = TRUE)
+  new <- use_template(
+    "circleci-config.yml",
+    ".circleci/config.yml",
+    data = list(package = project_name(), image = image),
+    ignore = TRUE
+  )
+  if (!new) {
+    return(invisible(FALSE))
+  }
+
+  circleci_activate(browse)
+  use_circleci_badge()
+  invisible(TRUE)
+}
+
+#' @section `use_circleci_badge()`:
+#' Only adds the [Circle CI](https://www.circleci.com) badge. Use for a project
+#'  where Circle CI is already configured.
+#' @export
+#' @rdname ci
+#' @export
+use_circleci_badge <- function() {
+  check_uses_github()
+  url <- glue("https://circleci.com/gh/{github_repo_spec()}")
+  img <- glue("{url}.svg?style=svg")
+  use_badge("CircleCI build status", url, img)
+}
+
+circleci_activate <- function(browse = is_interactive()) {
+  url <- glue("https://circleci.com/add-projects/gh/{github_owner()}")
+
+  ui_todo("Turn on CircleCI for your repo at {url}")
+  if (browse) {
+    utils::browseURL(url)
+  }
+}
+
+uses_circleci <- function(base_path = proj_get()) {
+  path <- glue("{base_path}/.circleci/config.yml")
+  file_exists(path)
+}
+
+check_uses_circleci <- function(base_path = proj_get()) {
+  if (uses_circleci(base_path)) {
+    return(invisible())
+  }
+
+  ui_stop(
+    "
+    Cannot detect that package {ui_field(project_name(base_path))} already uses CircleCI.
+    Do you need to run {ui_code('use_circleci()')}?
+    "
+  )
+}
