@@ -4,8 +4,15 @@
 #' `.Rbuildignore`, in the case of a package. The goal of a code of conduct is
 #' to foster an environment of inclusiveness, and to explicitly discourage
 #' inappropriate behaviour. The template comes from
-#' <http://contributor-covenant.org>, version 1:
-#' <http://contributor-covenant.org/version/1/0/0/>.
+#' <https://contributor-covenant.org>, version 2:
+#' <https://contributor-covenant.org/version/2/0>.
+#'
+#' If your package is going to CRAN, the link to the CoC in your README must
+#' be an absolute link to a rendered website as `CODE_OF_CONDUCT.md` is not
+#' included in the package sent to CRAN. `use_code_of_conduct()` will
+#' automatically generate this link if you use pkgdown and have set the
+#' `url` field in `pkgdown.yml`; otherwise it'll link to
+#' <https://contributor-covenant.org/version/2/0>.
 #'
 #' @param path Path of the directory to put `CODE_OF_CONDUCT.md` in, relative to
 #'   the active project. Passed along to [use_directory()]. Default is to locate
@@ -24,11 +31,14 @@ use_code_of_conduct <- function(path = NULL) {
     ignore = is_package() && is.null(path)
   )
 
+  href <- project_pkgdown_url() %||% "https://contributor-covenant.org/version/2/0"
+  href <- paste0(href, "/CODE_OF_CONDUCT.html")
+
   ui_todo("Don't forget to describe the code of conduct in your README:")
   ui_code_block("
-    Please note that the {ui_value(project_name())} project is released with a
-    [Contributor Code of Conduct]({save_as}).
-    By contributing to this project, you agree to abide by its terms."
+    ## Code of Conduct
+
+    Please note that the {project_name()} project is released with a [Contributor Code of Conduct]({href}). By contributing to this project, you agree to abide by its terms."
   )
 
   invisible(new)
