@@ -70,7 +70,7 @@ use_github_labels <- function(repo_spec = github_repo_spec(),
   check_github_token(auth_token)
 
   gh <- function(endpoint, ...) {
-    out <- gh::gh(
+    gh::gh(
       endpoint,
       ...,
       owner = spec_owner(repo_spec),
@@ -81,11 +81,6 @@ use_github_labels <- function(repo_spec = github_repo_spec(),
         "Accept" = "application/vnd.github.symmetra-preview+json"
       )
     )
-    if (identical(out[[1]], "")) {
-      list()
-    } else {
-      out
-    }
   }
 
   cur_labels <- gh("GET /repos/:owner/:repo/labels")
@@ -168,7 +163,7 @@ use_github_labels <- function(repo_spec = github_repo_spec(),
   cur_label_names <- label_attr("name", cur_labels)
 
   # Update colours
-  cur_label_colours <- rlang::set_names(
+  cur_label_colours <- set_names(
     label_attr("color", cur_labels), cur_label_names
   )
   if (identical(cur_label_colours[names(colours)], colours)) {
@@ -187,7 +182,7 @@ use_github_labels <- function(repo_spec = github_repo_spec(),
   }
 
   # Update descriptions
-  cur_label_descriptions <- rlang::set_names(
+  cur_label_descriptions <- set_names(
     label_attr("description", cur_labels), cur_label_names
   )
   if (identical(cur_label_descriptions[names(descriptions)], descriptions)) {
@@ -274,8 +269,7 @@ tidy_label_colours <- function() {
     "good first issue :heart:" = "CBBAB8",
     "help wanted :heart:" = "C5C295",
     "reprex" = "C5C295",
-    "tidy-dev-day :nerd_face:" = "CBBAB8",
-    "wip" = "E1B996"
+    "tidy-dev-day :nerd_face:" = "CBBAB8"
   )
 }
 
