@@ -10,9 +10,10 @@
 #' of the tidyverse conventions as possible, issues a few reminders, and
 #' activates the new package.
 #'
-#' * `use_tidy_ci()`: sets up [Travis CI](https://travis-ci.org) and
-#' [Codecov](https://codecov.io), ensuring that the package works on all
-#' versions of R starting at 3.1. It also ignores `compat-` and `deprec-`
+#' * `use_tidy_ci()`: sets up [Travis CI](https://travis-ci.com) and
+#' [Codecov](https://codecov.io), ensuring that the package is actively tested
+#' on the versions of R officially supported by the Tidyverse (current release,
+#' devel, and four previous versions). It also ignores `compat-` and `deprec-`
 #' files from code coverage.
 #'
 #' * `use_tidy_description()`: puts fields in standard order and alphabetises
@@ -22,12 +23,9 @@
 #'   programming with the tidy eval toolkit.
 #'
 #' * `use_tidy_style()`: styles source code according to the [tidyverse style
-#' guide](http://style.tidyverse.org). This function will overwrite files! See
+#' guide](https://style.tidyverse.org). This function will overwrite files! See
 #' below for usage advice.
 #'
-#' * `use_tidy_versions()`: pins all dependencies to require at least
-#'   the currently installed version.
-#'
 #' * `use_tidy_contributing()`: adds standard tidyverse contributing guidelines.
 #'
 #' * `use_tidy_issue_template()`: adds a standard tidyverse issue template.
@@ -46,9 +44,9 @@
 #' `use_tidy_coc()`.
 #'
 #' @section `use_tidy_style()`:
-#' Uses the [styler package](http://styler.r-lib.org) package to style all code
+#' Uses the [styler package](https://styler.r-lib.org) package to style all code
 #' in a package, project, or directory, according to the [tidyverse style
-#' guide](http://style.tidyverse.org).
+#' guide](https://style.tidyverse.org).
 #'
 #' **Warning:** This function will overwrite files! It is strongly suggested to
 #' only style files that are under version control or to first create a backup
@@ -97,7 +95,7 @@ create_tidy_package <- function(path,
 #' @export
 #' @rdname tidyverse
 #' @inheritParams use_travis
-use_tidy_ci <- function(browse = interactive()) {
+use_tidy_ci <- function(browse = rlang::is_interactive()) {
   check_uses_github()
 
   new_travis <- use_template(
@@ -107,7 +105,7 @@ use_tidy_ci <- function(browse = interactive()) {
   )
   use_template("codecov.yml", ignore = TRUE)
 
-  use_dependency("R", "Depends", min_version = "3.1")
+  use_dependency("R", "Depends", min_version = "3.2")
   use_dependency("covr", "Suggests")
   use_covr_ignore(c("R/deprec-*.R", "R/compat-*.R"))
 
@@ -131,40 +129,6 @@ use_tidy_description <- function() {
   invisible(TRUE)
 }
 
-#' @export
-#' @rdname tidyverse
-#' @param overwrite By default (`FALSE`), only dependencies without version
-#'   specifications will be modified. Set to `TRUE` to modify all dependencies.
-#' @param source Use "local" or "CRAN" package versions.
-use_tidy_versions <- function(overwrite = FALSE, source = c("local", "CRAN")) {
-  deps <- desc::desc_get_deps(proj_get())
-  deps <- update_versions(deps, overwrite = overwrite, source = source)
-  desc::desc_set_deps(deps, file = proj_get())
-
-  invisible(TRUE)
-}
-
-update_versions <- function(deps, overwrite = FALSE, source = c("local", "CRAN")) {
-  baserec <- base_and_recommended()
-  to_change <- !deps$package %in% c("R", baserec)
-  if (!overwrite) {
-    to_change <- to_change & deps$version == "*"
-  }
-
-  packages <- deps$package[to_change]
-  versions <- switch(match.arg(source),
-    local = purrr::map_chr(packages, package_version),
-    CRAN = utils::available.packages()[packages, "Version"]
-  )
-  deps$version[to_change] <- paste0(">= ", versions)
-
-  deps
-}
-
-package_version <- function(x) {
-  as.character(utils::packageVersion(x))
-}
-
 #' @export
 #' @rdname tidyverse
 use_tidy_eval <- function() {
@@ -178,15 +142,25 @@ use_tidy_eval <- function() {
   return(invisible(new))
 }
 
-
 #' @export
 #' @rdname tidyverse
 use_tidy_contributing <- function() {
-  use_directory(".github", ignore = TRUE)
+  use_dot_github()
   use_template(
     "tidy-contributing.md",
-    ".github/CONTRIBUTING.md",
-    data = list(package = project_name())
+    path(".github", "CONTRIBUTING.md"),
+    data = project_data()
+  )
+}
+
+#' @export
+#' @rdname tidyverse
+use_tidy_support <- function() {
+  use_dot_github()
+  use_template(
+    "tidy-support.md",
+    path(".github", "SUPPORT.md"),
+    data = project_data()
   )
 }
 
@@ -194,41 +168,36 @@ use_tidy_contributing <- function() {
 #' @export
 #' @rdname tidyverse
 use_tidy_issue_template <- function() {
-  use_directory(".github", ignore = TRUE)
+  use_dot_github()
+  use_directory(path(".github", "ISSUE_TEMPLATE"))
   use_template(
     "tidy-issue.md",
-    ".github/ISSUE_TEMPLATE.md"
+    path(".github", "ISSUE_TEMPLATE", "issue_template.md")
   )
 }
 
-
-#' @export
-#' @rdname tidyverse
-use_tidy_support <- function() {
-  use_directory(".github", ignore = TRUE)
-  use_template(
-    "tidy-support.md",
-    ".github/SUPPORT.md",
-    data = list(package = project_name())
-  )
-}
-
-
 #' @export
 #' @rdname tidyverse
 use_tidy_coc <- function() {
+  use_dot_github()
   use_code_of_conduct(path = ".github")
 }
 
 #' @export
 #' @rdname tidyverse
 use_tidy_github <- function() {
+  use_dot_github()
   use_tidy_contributing()
   use_tidy_issue_template()
   use_tidy_support()
   use_tidy_coc()
 }
 
+use_dot_github <- function(ignore = TRUE) {
+  use_directory(".github", ignore = ignore)
+  use_git_ignore("*.html", directory = ".github")
+}
+
 #' @export
 #' @rdname tidyverse
 use_tidy_style <- function(strict = TRUE) {
@@ -247,7 +216,7 @@ use_tidy_style <- function(strict = TRUE) {
       strict = strict
     )
   }
-  cat_line()
+  ui_line()
   ui_done("Styled project according to the tidyverse style guide")
   invisible(styled)
 }
@@ -356,7 +325,7 @@ use_tidy_thanks <- function(repo_spec = github_repo_spec(),
   contrib_link <- glue("[&#x0040;{contributors}](https://github.com/{contributors})")
 
   ui_done("Found {length(contributors)} contributors:")
-  ui_code_block(glue_collapse(contrib_link, sep = ", ", last = ", and "))
+  ui_code_block(glue_collapse(contrib_link, sep = ", ", last = ", and ") + glue("."))
 
   invisible(contributors)
 }
@@ -397,7 +366,9 @@ releases <- function(repo_spec = github_repo_spec()) {
     owner = spec_owner(repo_spec),
     repo = spec_repo(repo_spec)
   )
-  if (identical(res[[1]], "")) return(NULL)
+  if (length(res) < 1) {
+    return(NULL)
+  }
   pluck_chr(res, "tag_name")
 }
 
