@@ -13,11 +13,11 @@ test_that("use_lifecycle_badge() handles bad and good input", {
   expect_error_free(use_lifecycle_badge("stable"))
 })
 
-test_that("use_binder_badge() the github repository works", {
+test_that("use_binder_badge() needs a github repository", {
   skip_if(getRversion() < 3.2)
-  skip_if_no_git_config()
+  skip_if_no_git_user()
   scoped_temporary_project()
-  expect_error_free(use_binder_badge())
+  expect_error(use_binder_badge())
 })
 
 test_that("use_badge() does nothing if badge seems to pre-exist", {
@@ -31,7 +31,7 @@ test_that("default readme has placeholders / can add to empty badge block", {
   scoped_temporary_package()
   withr::local_options(list(usethis.quiet = FALSE))
 
-  expect_output(use_readme_md())
-  expect_output(use_cran_badge(), "Adding CRAN status badge")
+  expect_message(use_readme_md())
+  expect_message(use_cran_badge(), "Adding CRAN status badge")
   expect_silent(use_cran_badge())
 })
