@@ -2,18 +2,18 @@ context("use_template")
 
 test_that("can leave existing file unchanged, without an error", {
   scoped_temporary_package()
-  desc_lines_before <- readLines(proj_path("DESCRIPTION"))
+  desc_lines_before <- read_utf8(proj_path("DESCRIPTION"))
   expect_error_free(
     use_template("NEWS.md", "DESCRIPTION")
   )
-  desc_lines_after <- readLines(proj_path("DESCRIPTION"))
+  desc_lines_after <- read_utf8(proj_path("DESCRIPTION"))
   expect_identical(desc_lines_before, desc_lines_after)
 })
 
 # helpers -----------------------------------------------------------------
 
 test_that("find_template errors if template missing", {
-  expect_error(find_template("xxx"), "Could not find template")
+  expect_usethis_error(find_template("xxx"), "Could not find template")
 })
 
 test_that("find_template can find templates for tricky Rbuildignored files", {
