@@ -9,14 +9,12 @@ test_that("use_tutorial() checks its inputs", {
 })
 
 test_that("use_tutorial() creates a tutorial", {
-  skip_if(getRversion() < 3.2) ## mock doesn't seem to work on 3.1
-
   with_mock(
     ## need to pass the check re: whether learnr is installed
     `usethis:::is_installed` = function(pkg) TRUE, {
       scoped_temporary_package()
       use_tutorial(name = "aaa", title = "bbb")
-      tute_file <- path("inst", "tutorials", "aaa", ext = "Rmd")
+      tute_file <- path("inst", "tutorials", "aaa", "aaa", ext = "Rmd")
       expect_proj_file(tute_file)
       expect_equal(rmarkdown::yaml_front_matter(tute_file)$title, "bbb")
     }
