@@ -4,7 +4,7 @@ test_that("use_vignette() requires a package", {
   skip_if_not_installed("rmarkdown")
 
   scoped_temporary_project()
-  expect_error(use_vignette(), "not an R package")
+  expect_usethis_error(use_vignette(), "not an R package")
 })
 
 test_that("use_vignette() requires a `name`", {
@@ -26,7 +26,7 @@ test_that("use_vignette() does the promised setup", {
   scoped_temporary_package()
   use_vignette("name", "title")
 
-  ignores <- readLines(proj_path(".gitignore"), warn = FALSE)
+  ignores <- read_utf8(proj_path(".gitignore"))
   expect_true("inst/doc" %in% ignores)
 
   deps <- desc::desc_get_deps(proj_get())
